pub enum DataChannelState {
Connecting,
Open,
Closing,
Closed,
}Expand description
DataChannelState indicates the state of a data channel.
Variants
Connecting
DataChannelStateConnecting indicates that the data channel is being established. This is the initial state of DataChannel, whether created with create_data_channel, or dispatched as a part of an DataChannelEvent.
Open
DataChannelStateOpen indicates that the underlying data transport is established and communication is possible.
Closing
DataChannelStateClosing indicates that the procedure to close down the underlying data transport has started.
Closed
DataChannelStateClosed indicates that the underlying data transport has been closed or could not be established.